@@ -11,6 +11,8 @@ class Test_Dirs(object):
         self.temp = tmpdir
         self.core_dirs = inupypi.core.Dirs(self.temp.strpath)
         self.dirs = ['dir1', 'dir2', 'dir3', 'dir4']
+        self.abs_dirs = [tmpdir.join(dir) for dir in
+                         self.dirs]
 
     def test_class_instance(self):
         assert(isinstance(self.core_dirs, inupypi.core.Dirs))
@@ -24,4 +26,5 @@ class Test_Dirs(object):
             self.core_dirs = inupypi.core.Dirs(self.temp.strpath)
 
             assert(self.core_dirs.__parents__ == self.temp.strpath)
+        for dir_ in self.abs_dirs:
             assert(dir_ in self.core_dirs.__contents__)
